==> apache-camel-quarkus-2.5.0-src.zip: camel-quarkus-2.5.0/extensions-core/core/runtime/src/main/java/org/apache/camel/quarkus/core/CamelManagementEventBridge.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.core;

import java.util.Set;

import javax.enterprise.inject.spi.BeanManager;

import io.quarkus.arc.Arc;
import org.apache.camel.spi.CamelEvent;
import org.apache.camel.spi.EventNotifier;
import org.apache.camel.support.EventNotifierSupport;

/**
 * Bridges Camel Management events to CDI.
 *
 * @see EventNotifier
 */
public class CamelManagementEventBridge extends EventNotifierSupport {
    private final Set<String> observedManagementEvents;
    private BeanManager beanManager;

    public CamelManagementEventBridge(Set<String> observedManagementEvents) {
        this.observedManagementEvents = observedManagementEvents;
    }

    @Override
    protected void doInit() {
        beanManager = Arc.container().beanManager();
    }

    @Override
    public void notify(CamelEvent event) throws Exception {
        beanManager.getEvent().select(CamelEvent.class).fire(event);
    }

    @Override
    public boolean isEnabled(CamelEvent event) {
        return observedManagementEvents.contains(event.getClass().getSimpleName());
    }
}

==> apache-camel-quarkus-3.31.0-src.zip: camel-quarkus-3.31.0/extensions-core/core/runtime/src/main/java/org/apache/camel/quarkus/core/CamelManagementEventBridge.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.quarkus.core;

import java.util.Set;

import io.quarkus.arc.Arc;
import jakarta.enterprise.inject.spi.BeanManager;
import org.apache.camel.spi.CamelEvent;
import org.apache.camel.spi.EventNotifier;
import org.apache.camel.support.EventNotifierSupport;

/**
 * Bridges Camel Management events to CDI.
 *
 * @see EventNotifier
 */
public class CamelManagementEventBridge extends EventNotifierSupport {
    private final Set<String> observedManagementEvents;
    private BeanManager beanManager;

    public CamelManagementEventBridge(Set<String> observedManagementEvents) {
        this.observedManagementEvents = observedManagementEvents;
    }

    @Override
    protected void doInit() {
        beanManager = Arc.container().beanManager();
    }

    @Override
    public void notify(CamelEvent event) throws Exception {
        beanManager.getEvent().select(CamelEvent.class).fire(event);
    }

    @Override
    public boolean isEnabled(CamelEvent event) {
        return observedManagementEvents.contains(event.getClass().getSimpleName());
    }
}
